<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>just now</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 tin nhắn mới</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 phút trước</translation>
    </message>
</context>
</TS>